{% extends "base.html" %}
{% load i18n %}
{% block current_context %}
{% endblock %}
{% block content %}

    <div class="muses-list">
        {% include "_partials/pagination.html" %}
        {% for site_param in object_list %}
            <div class="muses-list-item"
                 onclick="location.href='{% url "muses_admin_site_param_detail" site_param.id %}'">
                <div>
                    {{ site_param.key }}
                </div>
                <div>
                    {{ site_param.value }}
                </div>
                <div class="muses-flex-row">
                    <div>
                        <a href="{% url "muses_admin_site_param_update" site_param.id %}" class="muses-button">
                            {% trans "Update" %}...
                        </a>
                    </div>
                    <div>
                        <a href="{% url "muses_admin_site_param_delete" site_param.id %}" class="muses-button">
                            {% trans "Delete" %}
                        </a>
                    </div>
                </div>
            </div>
        {% endfor %}
        {% include "_partials/pagination.html" %}
    </div>

{% endblock %}