{% extends "base.html" %}
{% load i18n %}
{% block title %}
    {{ site_title }} - {% trans "About us" %}
{% endblock %}
{% block nav_bar %}

    {% include '_partials/nav_bar_section.html' %}

{% endblock %}
{% block current_context %}
{% endblock %}
{% block search_bar %}
{% endblock %}
{% block tags_selector %}
{% endblock %}
{% block content %}
    <div class="muses-list">
        <div class="muses-show-text">

            <p>La Passion des Po&egrave;mes est une communaut&eacute; dont la mission est de permettre la libre
                expression
                des auteurs francophones dans le respect, l&apos;&eacute;coute et l&apos;entraide. Tous les auteurs, peu
                importe
                leur force en &eacute;criture, sont invit&eacute;s &agrave; venir partager leurs &eacute;crits sur le
                site.</p>

            <p>La Passion des Po&egrave;mes est dirig&eacute;e par une &eacute;quipe tr&egrave;s dynamique, toujours pr&ecirc;te
                &agrave; innover et qui est toujours &agrave; la disposition des membres.</p>

            <p>TBD</p>

            <p>La Passion des Po&egrave;mes a &eacute;t&eacute; con&ccedil;ue pour &ecirc;tre visionn&eacute;e &agrave;
                une r&eacute;solution d&apos;au moins 1024x768. De plus, nous vous recommandons fortement d&apos;utiliser
                un navigateur se conformant aux standards du W3C, comme Firefox.</p>

            <h1>Historique de La Passion des Po&egrave;mes</h1>

            <ul>
                <li>7 mars 2010 - LPDP f&ecirc;te aujourd&apos;hui son dixi&egrave;me anniversaire. Le site comportait
                    alors un peu moins de
                    12000 membres, 88143 po&egrave;mes, 11319 textes et un total 641517 envois et commentaires
                    confondus.
                </li>

                <li>juillet 2007 - Durant le mois de juillet 2007, notre 10,000e membre s&apos;est joint &agrave; notre
                    communaut&eacute;. Le
                    site comportait alors 70700 po&egrave;mes, 9500 textes et un total 468000 envois et commentaires
                    confondus.
                </li>

                <li> 19 mars 2007 - LPDP &agrave; la radio! En effet, nous avons eu la chance d&apos;&ecirc;tre
                    interview&eacute; par Sophie Jouanneau
                    de la radio France Bleu Is&egrave;re au sujet du site. L&apos;entretien d&apos;une dur&eacute;e d&apos;environ
                    5 minutes est disponible
                    ci-dessous :


                    &Eacute;couter :


                    T&eacute;l&eacute;charger en MP3 (5 MB)
                    Le site comportait alors 65900 po&egrave;mes, 9100 textes, 8800 membres inscrits et un total 425693
                    envois et
                    commentaires confondus.
                </li>
                <li>18 septembre 2006 - Ayant d&eacute;j&agrave; atteint les limites du serveur d&eacute;di&eacute;
                    virtuel sur lequel le site &eacute;tait
                    h&eacute;berg&eacute;, un nouveau d&eacute;m&eacute;nagement &eacute;tait de mise. Cette fois, LPDP
                    allait se payer son propre serveur d&eacute;di&eacute;.
                    H&eacute;berg&eacute; &agrave; Montr&eacute;al, le nouveau serveur permettra d&apos;offrir un
                    service de qualit&eacute; &agrave; un nombre toujours
                    grandissant d&apos;utilisateurs. De plus, le passage au nouveau serveur ammena aussi l&apos;introduction
                    d&apos;un syst&egrave;me
                    de clavardage en Flash.

                </li>
                <li>mars 2006 - D&ucirc; &agrave; une popularit&eacute; sans cesse grandissante, le site fut d&eacute;plac&eacute;
                    vers un serveur d&eacute;di&eacute;
                    virtuel. Ce transfert, ainsi que d&apos;importantes optimisations du code, permirent d&apos;offrir
                    aux visiteurs un
                    site beaucoup plus rapide. Parmi les nouveaut&eacute;s de l&apos;ann&eacute;e, notons la nouvelle
                    cat&eacute;gorie Le coin de la
                    technique ainsi que l&apos;album photo. En date de la fin mai 2006, le site comportait 50300 po&egrave;mes,
                    7800 textes,
                    6150 membres inscrits et un total 323700 envois et commentaires confondus.

                </li>
                <li>26 juillet 2005 - Apr&egrave;s une longue attente, le site se refit une beaut&eacute; dans sa cinqui&egrave;me
                    version. En
                    plus de permettre aux membres de choisir entre trois styles visuels diff&eacute;rents, le site
                    propose maintenant
                    des fonctions comme le correcteur orthographique en plus d&apos;&ecirc;tre b&acirc;ti sur du code
                    beaucoup plus robuste. Le
                    design graphique original fut con&ccedil;u par Martin Dub&eacute; et l&apos;engin de recherche fut
                    programm&eacute; par Joanie
                    Lessnick. Les logos sp&eacute;ciaux qui apparaissent lors d&apos;&eacute;v&egrave;nements sp&eacute;ciaux
                    tels l&apos;Halloween ou le Jour du
                    souvenir furent cr&eacute;&eacute;s par Josy. L&apos;ic&ocirc;ne du site fut r&eacute;alis&eacute;
                    conjointement par cokoon et Pinturicchio. Le
                    site comportait alors 37800 po&egrave;mes, 6300 textes et plus de 4500 po&egrave;tes inscrits.

                </li>
                <li>20 mai 2003 - En raison de graves probl&egrave;mes de serveur d&ucirc; au langage de programmation
                    utilis&eacute; pour faire
                    fonctionner le site (ASP), le site fut reprogramm&eacute; dans un langage plus moderne et plus
                    performant, PHP.
                    Pendant cette p&eacute;riode, le site fut quasi inaccessible pour environ 2 mois. On peut la consid&eacute;rer
                    comme la
                    p&eacute;riode noir de LPDP.

                </li>
                <li>4 mai 2002 - Dans la nuit du 3 au 4 mai 2002, La Passion des Po&egrave;mes changea de visage. Con&ccedil;ue
                    sp&eacute;cialement pour r&eacute;pondre aux besoins de la communaut&eacute;, la nouvelle version du
                    site a &eacute;t&eacute; d&eacute;velopp&eacute;e en
                    utilisant les plus r&eacute;centes technologies d&apos;automatisation pour rendre l&apos;exp&eacute;rience
                    des membres tout &agrave; fait
                    unique. Le site s&apos;est aussi dot&eacute; de son propre nom de domaine : lapassiondespoemes.com.
                    Cette version fut
                    r&eacute;alis&eacute;e en collaboration avec Marc Vieira-Cardinal.

                </li>
                <li>3 avril 2001 - R&eacute;ouverture du site sous un nouveau concept. En effet, en utilisant un
                    programme de groupe
                    de discussion automatis&eacute;, les po&egrave;mes se publiaient automatiquement d&egrave;s qu&apos;un
                    po&egrave;te les soumettait. Il y eut
                    aussi l&apos;introduction des forums de discussions. Mais un nouveau probl&egrave;me surgit : vu la
                    popularit&eacute; encore
                    une fois grandissante pour le site, la compagnie fournissant les services d&apos;h&eacute;bergement
                    et de gestion du
                    logiciel de groupe de discussion chargeait des tarifs exorbitants. C&apos;est pourquoi une nouvelle
                    version du
                    site vit le jour. Lors du transfert vers la nouvelle version, le site comportait 9742 po&egrave;mes
                    et 1226 po&egrave;tes
                    inscrits.

                </li>
                <li>juillet 2000 - Fermeture du site du &agrave; la popularit&eacute; grandissante et le niveau d&apos;envoi
                    qui augmentaient de
                    fa&ccedil;on exponentielle. &Agrave; sa fermeture, le site comportait 145 po&egrave;mes publi&eacute;s
                    (300 en attente de publication)
                    et 50 po&egrave;tes inscrits.

                </li>
                <li>7 mars 2000 - Cherchant en vain un site o&ugrave; publier ses po&egrave;mes, Fran&ccedil;ois Maillet
                    d&eacute;cida de cr&eacute;er son
                    propre site o&ugrave; les utilisateurs, peut importe leur force en &eacute;criture, seraient en
                    mesure de publier leurs
                    textes pour qu&apos;ils soient disponibles &agrave; tous. La Passion des Po&egrave;mes est n&eacute;e.
                    Sous son premier visage, le
                    site &eacute;tait fait de simple HTML et les mises &agrave; jour devaient &ecirc;tre faites
                    manuellement &agrave; chaque jour. D&egrave;s que
                    le site gagna un peu de popularit&eacute;, le maintien du site aurait n&eacute;cessit&eacute; toute
                    une &eacute;quipe travaillant &agrave;
                    temps plein. Le site fonctionnait alors avec l&apos;adresse lapassiondespoemes.cjb.net.
                </li>
            </ul>
            Historique des logos de LPDP


            Troisième version : 4 mai 2002 - 26 juillet 2005


            Troisième version : édition Noël


            Deuxième version : 3 avril 2001 - 4 mai 2002


            Première version : 7 mars 2000 - juillet 2000
        </div>
    </div>
{% endblock %}