@import "variables";

.muses-search-field {
  display: inline-flex;
  width: 80vw;


  > input[type=search] {
    margin: 0;
    padding: 0.5em;
    background: $search_bar_background;
    border-radius: 0.3em 0 0 0.3em;
    border: none;
    box-shadow: none;
    text-decoration: none;

    &:focus, &:active {
      outline: none;
    }
  }

  > button[type=submit] {
    border: none;
    margin: 0;
    padding: 0.5em;
    border-radius: 0 0.3em 0.3em 0;
    background: $search_bar_background;
    width: fit-content;
    color: invert($search_bar_background);
    box-shadow: none;

    &:focus, &:active {
      outline: none;
    }
  }
}
