.muses-item {
  border-radius: 1vmax;
  padding: 1vmax 2vmax;
  -webkit-transform: perspective(1px) translateZ(0);
  transform: perspective(1px) translateZ(0);
  box-shadow: 0 0 1px rgba(0, 0, 0, 0);
  -webkit-transition-duration: 0.3s;
  transition-duration: 0.3s;
  -webkit-transition-property: background;
  transition-property: background;

  &:hover {
    background: rgba(darken($background, 30%), 0.3);
    cursor: pointer;
  }
}