from .detail_view import DetailView
from .template_view import TemplateView
from .list_view import ListView
from .create_view import CreateView
from .delete_view import DeleteView
from .form_view import FormView
from .update_view import UpdateView
from .admin_create_view import AdminCreateView
from .admin_list_view import AdminListView
from .admin_delete_view import AdminDeleteView
from .admin_update_view import AdminUpdateView
from .admin_detail_view import AdminDetailView
from .mod_create_view import ModCreateView
from .mod_list_view import ModListView
from .mod_delete_view import ModDeleteView
from .mod_update_view import ModUpdateView
from .mod_detail_view import ModDetailView
from .cor_create_view import CorCreateView
from .cor_list_view import CorListView
from .cor_delete_view import CorDeleteView
from .cor_update_view import CorUpdateView
from .cor_detail_view import CorDetailView
