{% extends "base.html" %}
{% load i18n %}
{% block title %}
    {{ site_title }} - {% trans "New post" %}
{% endblock %}
{% block extra_meta %}
    {{ form.media }}
{% endblock %}
{% block pageloader %}
    <div class="pageloader"></div>
{% endblock %}
{% block current_context %}
{% endblock %}
{% block search_bar %}
{% endblock %}
{% block tags_selector %}
{% endblock %}
{% block content %}
    <form>
        {% csrf_token %}
        {{ form.as_div }}
    </form>
{% endblock %}